getFileNames: Files currently available for download

View source: R/getFileNames.R

getFileNamesR Documentation

Files currently available for download

Description

A convenience function, returning the base file names of the available downloads for the year and type arguments in getRetrosheet.

Usage

getFileNames()

Value

A named list of available single-season Retrosheet event and game-log zip files, and schedule text files. These file names are not intended to be passed to getRetrosheet, but is simply a fast way to determine if the desired data is available.

Examples


getFileNames()


retrosheet documentation built on April 20, 2026, 5:06 p.m.