{ - A data table with dimensions length(date) x length(glFields) if
date is not NULL, otherwise the row dimension is the nuber of games for the given year.}
gamelogFields- A character vector of possible values to choose from for the
glFlields argument in getPartialGamelog.
## Get Homerun and RBI info for August 25, 2012, with ballpark IDf <- grep("HR|RBI|Park", gamelogFields, value = TRUE)
getPartialGamelog(2012, glFields = f, date = "0825")